package com.diagbot.process;

import com.diagbot.dto.BillDTO;
import com.diagbot.dto.BillMsg;
import com.diagbot.dto.BillNeoDTO;
import com.diagbot.dto.DrugBillNeoDTO;
import com.diagbot.dto.WordCrfDTO;
import com.diagbot.rule.AgeRule;
import com.diagbot.rule.DiseaseRule;
import com.diagbot.rule.SexRule;
import com.diagbot.util.CoreUtil;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;

/**
 * @Description: 开单总入口
 * @author: zhoutg
 * @time: 2018/8/6 9:11
 */
@Component
public class BillProcess {

    public BillDTO process(List<BillNeoDTO> billNeoDTOList, WordCrfDTO wordCrfDTO) {
        BillDTO billDTO = new BillDTO();
        // 化验规则处理
        processBillWithLis(billNeoDTOList, wordCrfDTO, billDTO);
        // 辅检规则处理
        processBillWithPacs(billNeoDTOList, wordCrfDTO, billDTO);
        // 药品规则处理
        processBillWithDrug(billNeoDTOList, wordCrfDTO, billDTO);
        return billDTO;
    }

    /**
     * 化验规则处理
     *
     * @param billNeoDTOList
     * @param wordCrfDTO
     * @param billDTO
     */
    public void processBillWithLis(List<BillNeoDTO> billNeoDTOList, WordCrfDTO wordCrfDTO, BillDTO billDTO) {

    }

    /**
     * 辅检规则处理
     *
     * @param billNeoDTOList
     * @param wordCrfDTO
     * @param billDTO
     */
    public void processBillWithPacs(List<BillNeoDTO> billNeoDTOList, WordCrfDTO wordCrfDTO, BillDTO billDTO) {

    }

    /**
     * 药品规则处理
     *
     * @param billNeoDTOList
     * @param wordCrfDTO
     * @param billDTO
     */
    public void processBillWithDrug(List<BillNeoDTO> billNeoDTOList, WordCrfDTO wordCrfDTO, BillDTO billDTO) {
        List<BillMsg> drugBill = new ArrayList<>();
        for (BillNeoDTO bill : billNeoDTOList) {
            List<DrugBillNeoDTO> drugBillNeoDTOList = bill.getDrugBillNeoDTOList();
            for (DrugBillNeoDTO drug : drugBillNeoDTOList) {
                // 性别
                BillMsg sexMsg = SexRule.compareSexWithBill(drug.getGender(), wordCrfDTO, bill.getName());
                CoreUtil.addBeanToList(drugBill, sexMsg);

                // 诊断
                BillMsg billMsg_disease = DiseaseRule.compareDiseaseWithBill(drug.getDisease(), wordCrfDTO, bill.getName());
                CoreUtil.addBeanToList(drugBill, billMsg_disease);

                // 年龄
                BillMsg ageMsg = AgeRule.compareAgeWithBill(drug.getAgeNeoDTO(), wordCrfDTO, bill.getName());
                CoreUtil.addBeanToList(drugBill, ageMsg);
            }
        }
        billDTO.setDrugBill(drugBill);
    }

}
